@@ -16,13 +16,17 @@ typedef struct {
 	GtkWidget *basic_frame;
 	GtkEntry  *name;
 	GtkCombo  *type;
+	/*GtkLabel  *type_label;*/
 
 	/* Image frame */
 	GtkWidget *image_frame;
 	GtkWidget *image_widget;
 	GtkEntry  *image_entry;
-	GtkEntry  *root;
+	GtkCombo  *root;
+	GtkWidget *initrd_widget;
+	GtkEntry  *initrd_entry;
 	GtkEntry  *append;
+	GtkButton *append_browse;
 
 	/* Other frame */
 	GtkWidget *other_frame;
@@ -35,10 +39,6 @@ void             boot_settings_gui_setup    (BootSettingsGui *gui, GtkWidget *to
 gboolean         boot_settings_gui_save     (BootSettingsGui *gui, gboolean check);
 void             boot_settings_gui_error    (GtkWindow *parent, gchar *error);
 void             boot_settings_gui_destroy  (BootSettingsGui *gui);
-
-/* Callbacks */ 
-
-void             on_boot_add_clicked        (GtkButton *button, gpointer data);
-void             on_boot_settings_clicked   (GtkButton *button, gpointer data);
+GList            *settings_type_list        (void);
 
 #endif /* BOOT_SETTINGS_H */
